from __future__ import absolute_import

from arya.build import git
from pbr.packaging import _get_version_from_pkg_metadata


def get_git_version():
    tag = git.tag()
    count = git.count(tag)
    short = git.short()

    if not tag:
        return '0.dev{count}+{short}'.format(count=count, short=short)
    if count == '0':
        return tag
    return '{tag}.dev{count}+{short}'.format(tag=tag, count=count, short=short)


def get_version(package):
    version = _get_version_from_pkg_metadata(package)
    if version:
        return version

    version = get_git_version()
    return version



from pbr import util

from arya.build.version import get_version


def apply_options(dist, attrs):
    for key, val in attrs.items():
        if hasattr(dist.metadata, 'set_' + key):
            getattr(dist.metadata, 'set_' + key)(val)
        elif hasattr(dist.metadata, key):
            setattr(dist.metadata, key, val)
        elif hasattr(dist, key):
            setattr(dist, key, val)
        else:
            msg = 'Unknown distribution option: %s' % repr(key)
            warnings.warn(msg)


def get_attrs():
    attrs = util.cfg_to_args()
    attrs['version'] = get_version(attrs['name'])
    return attrs


def arya(dist, attr, value):
    attrs = get_attrs()
    apply_options(dist, attrs)



from subprocess import check_output, CalledProcessError, DEVNULL


def command(*args):
    out = check_output(['git'] + list(args), stderr=DEVNULL)
    return out.decode('utf-8').strip()


def count(tag=None):
    if tag:
        return command('rev-list', '--count', '{}..HEAD'.format(tag))
    else:
        return command('rev-list', '--count', 'HEAD')


def short():
    return command('rev-parse', '--short', 'HEAD')


def tag():
    try:
        return command('describe', '--abbrev=0')
    except CalledProcessError:
        pass
